.. _Watchdog: https://github.com/gorakhargosh/watchdog
.. _click: http://click.pocoo.org/6/

========
Boussole
========

Aims to reproduce the useful Compass commandline tool behavior for 'build' and 'watch' actions.

This is currently in Alpha stage construction.

Links
*****

* Read the documentation on `Read the docs <http://boussole.readthedocs.org/>`_;
* Download its `PyPi package <http://pypi.python.org/pypi/boussole>`_;
* Clone it on its `Github repository <https://github.com/sveetch/boussole>`_;

Requires
********

* `Watchdog`_ == 0.8.3;
* `click`_ == 6.2;
